/*
	mactioneditsdialog.cpp - action edit dialog
	Copyright (C) 2003  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "mactioneditdialog.h"
#include "mtip.h"

#include <qlayout.h>

#include <klocale.h>

/* constructor */

MActionEditDialog::MActionEditDialog(QWidget *parent, const char *name)
	: KDialogBase(
		Plain,
		i18n("Edit"),
		Ok | Cancel | Help,
		Ok, // default button
		parent,
		name,
		TRUE, // modal
		TRUE // separator
	),
	// init
	_userCommand("")
{
	QFrame *w = plainPage();
	QVBoxLayout *l = new QVBoxLayout(w, 2);

	// action name
	l_what = new QLabel(w, "QLabel::l_what");
	l_what->setAlignment(AlignCenter);
	l->addWidget(l_what);

	// method label
	QLabel *l_method = new QLabel(i18n("&Method:"), w, "QLabel::l_method");
	l->addWidget(l_method);

	// method combo box
	methods = new QComboBox(w, "QComboBox::method");
	l_method->setBuddy(methods);
	connect(
		methods, SIGNAL(activated(int)),
		this, SLOT(methodChangeSlot(int)));
	l->addWidget(methods);

	// command label
	l_command = new QLabel(i18n("Comm&and:"), w, "QLabel::l_command");
	l->addWidget(l_command);

	// command edit line
	command = new KLineEdit(w, "KLineEdit::command");
	l_command->setBuddy(command);
	l->addWidget(command);

	// tip
	MTip *t_progs = new MTip(MTip::TipType_Warning, w, "MTip::t_progs");
	t_progs->setTipText(
		i18n("In most cases you need privileges to shut down system " \
			"(e.g. run /sbin/reboot or /sbin/shutdown)") + "<br><br>" +
		i18n("Manuals:") +
		"<ul>" \
		"<li><a href=\"man:/halt\">halt, poweroff, reboot</a></li>" \
		"<li><a href=\"man:/shutdown\">shutdown</a></li>" \
		"<li><a href=\"man:/xlock\">xlock</a></li>" \
		"</ul>"
	);
	l->addWidget(t_progs);

	// focus combo box
	methods->setFocus();
}

/* destructor */

MActionEditDialog::~MActionEditDialog()
{
}

/* public */

void MActionEditDialog::setAction(const MMainWindow::What value)
{
	l_what->setText(mainWindow->getActionName(value));
}

void MActionEditDialog::setActionMethod(const MMainWindow::Method value) const
{
	methods->setCurrentItem(value);
	l_command->setEnabled(value == MMainWindow::Method_UserCommand);
	command->setEnabled(value == MMainWindow::Method_UserCommand);
	switch (value)
	{
		case MMainWindow::Method_KDE:
			command->setText("");
			break;
		case MMainWindow::Method_DefaultCommand:
			command->setText(methods->text(MMainWindow::Method_DefaultCommand));
			break;
		case MMainWindow::Method_UserCommand:
			command->setText(_userCommand);
			break;
	}
}

/* private slots */

void MActionEditDialog::methodChangeSlot(int index)
{
	if (command->isEnabled())
		_userCommand = command->text();
	setActionMethod((MMainWindow::Method)index);
}
